from distutils.core import setup

setup(
  name = 'apex_stats',         # How you named your package folder (MyLib)
  packages = ['apex_stats'],   # Chose the same as "name"
  version = '0.1.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'API wrapper for https://apex.tracker.gg',   # Give a short description about your library
  author = 'Bobo Kara',                   # Type in your name
  author_email = 'yamozha16@protonmail.ch',      # Type in your E-Mail
  url = 'https://github.com/yamozha/apex_stats',   # Provide either the link to your github or to your website
)
